@@ -72,7 +72,7 @@ public:
       @param other is the incidence to copy.
       @since 4.14
      */
-    Todo(const Incidence &other);
+    Todo(const Incidence &other); //krazy:exclude=explicit (copy ctor)
 
     /**
       Destroys a to-do.
@@ -82,18 +82,18 @@ public:
     /**
       @copydoc IncidenceBase::type()
     */
-    IncidenceType type() const Q_DECL_OVERRIDE;
+    IncidenceType type() const override;
 
     /**
       @copydoc IncidenceBase::typeStr()
     */
-    QByteArray typeStr() const Q_DECL_OVERRIDE;
+    QByteArray typeStr() const override;
 
     /**
       Returns an exact copy of this todo. The returned object is owned by the caller.
       @return A pointer to a Todo containing an exact copy of this object.
     */
-    Todo *clone() const Q_DECL_OVERRIDE;
+    Todo *clone() const override;
 
     /**
       Sets due date and time.
@@ -104,7 +104,7 @@ public:
       current occurrence will be returned. If non-recurrent, the normal due
       date will be returned.
     */
-    void setDtDue(const KDateTime &dtDue, bool first = false);
+    void setDtDue(const QDateTime &dtDue, bool first = false);
 
     /**
       Returns the todo due datetime.
@@ -113,9 +113,9 @@ public:
       occurrence will be returned. If false and recurrent, the datetime of the
       current occurrence will be returned. If non-recurrent, the normal due
       datetime will be returned.
-      @return A KDateTime containing the todo due datetime.
+      @return A QDateTime containing the todo due datetime.
     */
-    KDateTime dtDue(bool first = false) const;
+    QDateTime dtDue(bool first = false) const;
 
     /**
       Returns if the todo has a due datetime.
@@ -132,7 +132,7 @@ public:
     /**
       @copydoc IncidenceBase::dtStart()
     */
-    KDateTime dtStart() const Q_DECL_OVERRIDE;
+    QDateTime dtStart() const override;
 
     /**
       Returns the start datetime of the todo.
@@ -142,9 +142,9 @@ public:
       will be returned.
       If false and the todo recurs, the relative start datetime will be returned,
       based on the datetime returned by dtRecurrence().
-      @return A KDateTime for the start datetime of the todo.
+      @return A QDateTime for the start datetime of the todo.
     */
-    KDateTime dtStart(bool first) const;
+    QDateTime dtStart(bool first) const;
 
     /**
       Returns if the todo is 100% completed.
@@ -186,10 +186,10 @@ public:
     /**
       Returns the to-do was completion datetime.
 
-      @return A KDateTime for the completeion datetime of the to-do.
+      @return A QDateTime for the completeion datetime of the to-do.
       @see hasCompletedDate()
     */
-    KDateTime completed() const;
+    QDateTime completed() const;
 
     /**
       Sets date and time of completion.
@@ -197,7 +197,7 @@ public:
       @param completeDate is the to-do completion date.
       @see completed(), hasCompletedDate()
     */
-    void setCompleted(const KDateTime &completeDate);
+    void setCompleted(const QDateTime &completeDate);
 
     /**
       Returns if the to-do has a completion datetime.
@@ -243,25 +243,24 @@ public:
     /**
       @copydoc IncidenceBase::shiftTimes()
     */
-    void shiftTimes(const KDateTime::Spec &oldSpec,
-                    const KDateTime::Spec &newSpec) Q_DECL_OVERRIDE;
+    void shiftTimes(const QTimeZone &oldZone, const QTimeZone &newZone) override;
 
     /**
       @copydoc IncidenceBase::setAllDay().
     */
-    void setAllDay(bool allDay) Q_DECL_OVERRIDE;
+    void setAllDay(bool allDay) override;
 
     /**
       Sets the due date/time of the current occurrence if recurrent.
 
       @param dt is the
     */
-    void setDtRecurrence(const KDateTime &dt);
+    void setDtRecurrence(const QDateTime &dt);
 
     /**
       Returns the due date/time of the current occurrence if recurrent.
     */
-    KDateTime dtRecurrence() const;
+    QDateTime dtRecurrence() const;
 
     /**
       Returns true if the @p date specified is one on which the to-do will
@@ -270,10 +269,9 @@ public:
       the recur start and today.
 
       @param date is the date to check.
-      @param timeSpec is the
+      @param timeZone is the time zone
     */
-    bool recursOn(const QDate &date,
-                  const KDateTime::Spec &timeSpec) const Q_DECL_OVERRIDE;
+    bool recursOn(const QDate &date, const QTimeZone &timeZone) const override;
 
     /**
       Returns true if this todo is overdue (e.g. due date is lower than today
@@ -285,28 +283,28 @@ public:
     /**
       @copydoc IncidenceBase::dateTime()
     */
-    KDateTime dateTime(DateTimeRole role) const Q_DECL_OVERRIDE;
+    QDateTime dateTime(DateTimeRole role) const override;
 
     /**
       @copydoc IncidenceBase::setDateTime()
     */
-    void setDateTime(const KDateTime &dateTime, DateTimeRole role) Q_DECL_OVERRIDE;
+    void setDateTime(const QDateTime &dateTime, DateTimeRole role) override;
 
     /**
        @copydoc IncidenceBase::mimeType()
     */
-    QLatin1String mimeType() const Q_DECL_OVERRIDE;
+    QLatin1String mimeType() const override;
 
     /**
        @copydoc Incidence::iconName()
     */
-    QLatin1String iconName(const KDateTime &recurrenceId = KDateTime()) const Q_DECL_OVERRIDE;
+    QLatin1String iconName(const QDateTime &recurrenceId = {}) const override;
 
     /**
        @copydoc
        Incidence::supportsGroupwareCommunication()
     */
-    bool supportsGroupwareCommunication() const Q_DECL_OVERRIDE;
+    bool supportsGroupwareCommunication() const override;
 
     /**
        Returns the Akonadi specific sub MIME type of a KCalCore::Todo.
@@ -318,23 +316,23 @@ protected:
       Compare this with @p todo for equality.
       @param todo is the to-do to compare.
     */
-    bool equals(const IncidenceBase &todo) const Q_DECL_OVERRIDE;
+    bool equals(const IncidenceBase &todo) const override;
 
     /**
       @copydoc IncidenceBase::assign()
     */
-    IncidenceBase &assign(const IncidenceBase &other) Q_DECL_OVERRIDE;
+    IncidenceBase &assign(const IncidenceBase &other) override;
 
     /**
       @copydoc IncidenceBase::virtual_hook()
     */
-    void virtual_hook(VirtualHook id, void *data) Q_DECL_OVERRIDE;
+    void virtual_hook(VirtualHook id, void *data) override;
 
 private:
     /**
       @copydoc IncidenceBase::accept()
     */
-    bool accept(Visitor &v, const IncidenceBase::Ptr &incidence) Q_DECL_OVERRIDE;
+    bool accept(Visitor &v, const IncidenceBase::Ptr &incidence) override;
 
     /**
       Disabled, otherwise could be dangerous if you subclass Todo.
